==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/StringMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StringMatchFluentImpl<A extends StringMatchFluent<A>> extends BaseFluent<A> implements StringMatchFluent<A>{
  public StringMatchFluentImpl() {
  }
  public StringMatchFluentImpl(StringMatch instance) {
    this.withMatchType(instance.getMatchType()); 
  }
  private VisitableBuilder<? extends IsStringMatchMatchType,?> matchType;
  
  /**
   * This method has been deprecated, please use method buildMatchType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsStringMatchMatchType getMatchType() {
    return this.matchType!=null?this.matchType.build():null;
  }
  public IsStringMatchMatchType buildMatchType() {
    return this.matchType!=null?this.matchType.build():null;
  }
  public A withMatchType(IsStringMatchMatchType matchType) {
    if (matchType instanceof StringMatchExact){ this.matchType= new StringMatchExactBuilder((StringMatchExact)matchType); _visitables.get("matchType").add(this.matchType);}
    if (matchType instanceof StringMatchPrefix){ this.matchType= new StringMatchPrefixBuilder((StringMatchPrefix)matchType); _visitables.get("matchType").add(this.matchType);}
    if (matchType instanceof StringMatchRegex){ this.matchType= new StringMatchRegexBuilder((StringMatchRegex)matchType); _visitables.get("matchType").add(this.matchType);}
    return (A) this;
  }
  public Boolean hasMatchType() {
    return this.matchType != null;
  }
  public A withStringMatchExactType(StringMatchExact stringMatchExactType) {
    _visitables.get("matchType").remove(this.matchType);
    if (stringMatchExactType!=null){ this.matchType= new StringMatchExactBuilder(stringMatchExactType); _visitables.get("matchType").add(this.matchType);} else { this.matchType = null; _visitables.get("matchType").remove(this.matchType); } return (A) this;
  }
  public StringMatchFluent.StringMatchExactTypeNested<A> withNewStringMatchExactType() {
    return new StringMatchFluentImpl.StringMatchExactTypeNestedImpl();
  }
  public StringMatchFluent.StringMatchExactTypeNested<A> withNewStringMatchExactTypeLike(StringMatchExact item) {
    return new StringMatchFluentImpl.StringMatchExactTypeNestedImpl(item);
  }
  public A withNewStringMatchExactType(String exact) {
    return (A)withStringMatchExactType(new StringMatchExact(exact));
  }
  public A withStringMatchPrefixType(StringMatchPrefix stringMatchPrefixType) {
    _visitables.get("matchType").remove(this.matchType);
    if (stringMatchPrefixType!=null){ this.matchType= new StringMatchPrefixBuilder(stringMatchPrefixType); _visitables.get("matchType").add(this.matchType);} else { this.matchType = null; _visitables.get("matchType").remove(this.matchType); } return (A) this;
  }
  public StringMatchFluent.StringMatchPrefixTypeNested<A> withNewStringMatchPrefixType() {
    return new StringMatchFluentImpl.StringMatchPrefixTypeNestedImpl();
  }
  public StringMatchFluent.StringMatchPrefixTypeNested<A> withNewStringMatchPrefixTypeLike(StringMatchPrefix item) {
    return new StringMatchFluentImpl.StringMatchPrefixTypeNestedImpl(item);
  }
  public A withNewStringMatchPrefixType(String prefix) {
    return (A)withStringMatchPrefixType(new StringMatchPrefix(prefix));
  }
  public A withStringMatchRegexType(StringMatchRegex stringMatchRegexType) {
    _visitables.get("matchType").remove(this.matchType);
    if (stringMatchRegexType!=null){ this.matchType= new StringMatchRegexBuilder(stringMatchRegexType); _visitables.get("matchType").add(this.matchType);} else { this.matchType = null; _visitables.get("matchType").remove(this.matchType); } return (A) this;
  }
  public StringMatchFluent.StringMatchRegexTypeNested<A> withNewStringMatchRegexType() {
    return new StringMatchFluentImpl.StringMatchRegexTypeNestedImpl();
  }
  public StringMatchFluent.StringMatchRegexTypeNested<A> withNewStringMatchRegexTypeLike(StringMatchRegex item) {
    return new StringMatchFluentImpl.StringMatchRegexTypeNestedImpl(item);
  }
  public A withNewStringMatchRegexType(String regex) {
    return (A)withStringMatchRegexType(new StringMatchRegex(regex));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StringMatchFluentImpl that = (StringMatchFluentImpl) o;
    if (matchType != null ? !matchType.equals(that.matchType) :that.matchType != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchType,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchType != null) { sb.append("matchType:"); sb.append(matchType); }
    sb.append("}");
    return sb.toString();
  }
  class StringMatchExactTypeNestedImpl<N> extends StringMatchExactFluentImpl<StringMatchFluent.StringMatchExactTypeNested<N>> implements StringMatchFluent.StringMatchExactTypeNested<N>,Nested<N>{
    StringMatchExactTypeNestedImpl(StringMatchExact item) {
      this.builder = new StringMatchExactBuilder(this, item);
    }
    StringMatchExactTypeNestedImpl() {
      this.builder = new StringMatchExactBuilder(this);
    }
    StringMatchExactBuilder builder;
    public N and() {
      return (N) StringMatchFluentImpl.this.withMatchType(builder.build());
    }
    public N endStringMatchExactType() {
      return and();
    }
    
  }
  class StringMatchPrefixTypeNestedImpl<N> extends StringMatchPrefixFluentImpl<StringMatchFluent.StringMatchPrefixTypeNested<N>> implements StringMatchFluent.StringMatchPrefixTypeNested<N>,Nested<N>{
    StringMatchPrefixTypeNestedImpl(StringMatchPrefix item) {
      this.builder = new StringMatchPrefixBuilder(this, item);
    }
    StringMatchPrefixTypeNestedImpl() {
      this.builder = new StringMatchPrefixBuilder(this);
    }
    StringMatchPrefixBuilder builder;
    public N and() {
      return (N) StringMatchFluentImpl.this.withMatchType(builder.build());
    }
    public N endStringMatchPrefixType() {
      return and();
    }
    
  }
  class StringMatchRegexTypeNestedImpl<N> extends StringMatchRegexFluentImpl<StringMatchFluent.StringMatchRegexTypeNested<N>> implements StringMatchFluent.StringMatchRegexTypeNested<N>,Nested<N>{
    StringMatchRegexTypeNestedImpl(StringMatchRegex item) {
      this.builder = new StringMatchRegexBuilder(this, item);
    }
    StringMatchRegexTypeNestedImpl() {
      this.builder = new StringMatchRegexBuilder(this);
    }
    StringMatchRegexBuilder builder;
    public N and() {
      return (N) StringMatchFluentImpl.this.withMatchType(builder.build());
    }
    public N endStringMatchRegexType() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/StringMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StringMatchFluentImpl<A extends StringMatchFluent<A>> extends BaseFluent<A> implements StringMatchFluent<A>{
  public StringMatchFluentImpl() {
  }
  public StringMatchFluentImpl(StringMatch instance) {
    if (instance != null) {
      this.withMatchType(instance.getMatchType());
    }
  }
  private VisitableBuilder<? extends IsStringMatchMatchType,?> matchType;
  
  /**
   * This method has been deprecated, please use method buildMatchType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsStringMatchMatchType getMatchType() {
    return this.matchType!=null?this.matchType.build():null;
  }
  public IsStringMatchMatchType buildMatchType() {
    return this.matchType!=null?this.matchType.build():null;
  }
  public A withMatchType(IsStringMatchMatchType matchType) {
    if (matchType==null){ this.matchType = null; _visitables.remove("matchType"); return (A) this;}
    if (matchType instanceof StringMatchExact){ this.matchType= new StringMatchExactBuilder((StringMatchExact)matchType); _visitables.get("matchType").clear(); _visitables.get("matchType").add(this.matchType);}
    if (matchType instanceof StringMatchPrefix){ this.matchType= new StringMatchPrefixBuilder((StringMatchPrefix)matchType); _visitables.get("matchType").clear(); _visitables.get("matchType").add(this.matchType);}
    if (matchType instanceof StringMatchRegex){ this.matchType= new StringMatchRegexBuilder((StringMatchRegex)matchType); _visitables.get("matchType").clear(); _visitables.get("matchType").add(this.matchType);}
    VisitableBuilder<? extends IsStringMatchMatchType,?> builder = builderOf(matchType); _visitables.get("matchType").clear();_visitables.get("matchType").add(builder);this.matchType = builder;
    return (A) this;
  }
  public Boolean hasMatchType() {
    return this.matchType != null;
  }
  public A withStringMatchExactType(StringMatchExact stringMatchExactType) {
    _visitables.get("matchType").remove(this.matchType);
    if (stringMatchExactType!=null){ this.matchType= new StringMatchExactBuilder(stringMatchExactType); _visitables.get("matchType").add(this.matchType);} else { this.matchType = null; _visitables.get("matchType").remove(this.matchType); } return (A) this;
  }
  public StringMatchFluentImpl.StringMatchExactTypeNested<A> withNewStringMatchExactType() {
    return new StringMatchFluentImpl.StringMatchExactTypeNestedImpl();
  }
  public StringMatchFluentImpl.StringMatchExactTypeNested<A> withNewStringMatchExactTypeLike(StringMatchExact item) {
    return new StringMatchFluentImpl.StringMatchExactTypeNestedImpl(item);
  }
  public A withNewStringMatchExactType(String exact) {
    return (A)withStringMatchExactType(new StringMatchExact(exact));
  }
  public A withStringMatchPrefixType(StringMatchPrefix stringMatchPrefixType) {
    _visitables.get("matchType").remove(this.matchType);
    if (stringMatchPrefixType!=null){ this.matchType= new StringMatchPrefixBuilder(stringMatchPrefixType); _visitables.get("matchType").add(this.matchType);} else { this.matchType = null; _visitables.get("matchType").remove(this.matchType); } return (A) this;
  }
  public StringMatchFluentImpl.StringMatchPrefixTypeNested<A> withNewStringMatchPrefixType() {
    return new StringMatchFluentImpl.StringMatchPrefixTypeNestedImpl();
  }
  public StringMatchFluentImpl.StringMatchPrefixTypeNested<A> withNewStringMatchPrefixTypeLike(StringMatchPrefix item) {
    return new StringMatchFluentImpl.StringMatchPrefixTypeNestedImpl(item);
  }
  public A withNewStringMatchPrefixType(String prefix) {
    return (A)withStringMatchPrefixType(new StringMatchPrefix(prefix));
  }
  public A withStringMatchRegexType(StringMatchRegex stringMatchRegexType) {
    _visitables.get("matchType").remove(this.matchType);
    if (stringMatchRegexType!=null){ this.matchType= new StringMatchRegexBuilder(stringMatchRegexType); _visitables.get("matchType").add(this.matchType);} else { this.matchType = null; _visitables.get("matchType").remove(this.matchType); } return (A) this;
  }
  public StringMatchFluentImpl.StringMatchRegexTypeNested<A> withNewStringMatchRegexType() {
    return new StringMatchFluentImpl.StringMatchRegexTypeNestedImpl();
  }
  public StringMatchFluentImpl.StringMatchRegexTypeNested<A> withNewStringMatchRegexTypeLike(StringMatchRegex item) {
    return new StringMatchFluentImpl.StringMatchRegexTypeNestedImpl(item);
  }
  public A withNewStringMatchRegexType(String regex) {
    return (A)withStringMatchRegexType(new StringMatchRegex(regex));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchFluentImpl that = (StringMatchFluentImpl) o;
    if (!java.util.Objects.equals(matchType, that.matchType)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchType,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchType != null) { sb.append("matchType:"); sb.append(matchType); }
    sb.append("}");
    return sb.toString();
  }
  class StringMatchExactTypeNestedImpl<N> extends StringMatchExactFluentImpl<StringMatchFluentImpl.StringMatchExactTypeNested<N>> implements StringMatchFluentImpl.StringMatchExactTypeNested<N>,Nested<N>{
    StringMatchExactTypeNestedImpl(StringMatchExact item) {
      this.builder = new StringMatchExactBuilder(this, item);
    }
    StringMatchExactTypeNestedImpl() {
      this.builder = new StringMatchExactBuilder(this);
    }
    StringMatchExactBuilder builder;
    public N and() {
      return (N) StringMatchFluentImpl.this.withMatchType(builder.build());
    }
    public N endStringMatchExactType() {
      return and();
    }
    
  }
  class StringMatchPrefixTypeNestedImpl<N> extends StringMatchPrefixFluentImpl<StringMatchFluentImpl.StringMatchPrefixTypeNested<N>> implements StringMatchFluentImpl.StringMatchPrefixTypeNested<N>,Nested<N>{
    StringMatchPrefixTypeNestedImpl(StringMatchPrefix item) {
      this.builder = new StringMatchPrefixBuilder(this, item);
    }
    StringMatchPrefixTypeNestedImpl() {
      this.builder = new StringMatchPrefixBuilder(this);
    }
    StringMatchPrefixBuilder builder;
    public N and() {
      return (N) StringMatchFluentImpl.this.withMatchType(builder.build());
    }
    public N endStringMatchPrefixType() {
      return and();
    }
    
  }
  class StringMatchRegexTypeNestedImpl<N> extends StringMatchRegexFluentImpl<StringMatchFluentImpl.StringMatchRegexTypeNested<N>> implements StringMatchFluentImpl.StringMatchRegexTypeNested<N>,Nested<N>{
    StringMatchRegexTypeNestedImpl(StringMatchRegex item) {
      this.builder = new StringMatchRegexBuilder(this, item);
    }
    StringMatchRegexTypeNestedImpl() {
      this.builder = new StringMatchRegexBuilder(this);
    }
    StringMatchRegexBuilder builder;
    public N and() {
      return (N) StringMatchFluentImpl.this.withMatchType(builder.build());
    }
    public N endStringMatchRegexType() {
      return and();
    }
    
  }
  
}
